@@ -2,14 +2,14 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from .product import *
+from . import product
 
 
 def register():
     Pool.register(
-        Template,
-        Taxon,
-        Cultivar,
-        CultivarGroup,
-        Cultivar_CultivarGroup,
+        product.Template,
+        product.Taxon,
+        product.Cultivar,
+        product.CultivarGroup,
+        product.Cultivar_CultivarGroup,
         module='product_classification_taxonomic', type_='model')
