@@ -2,7 +2,7 @@
 # this repository contains the full copyright notices and license terms.
 
 try:
-    from trytond.modules.product_classification_taxonomic.tests.test_product_classification_taxonomic import suite
+    from trytond.modules.product_classification_taxonomic.tests.test_product_classification_taxonomic import suite  # noqa: E501
 except ImportError:
     from .test_product_classification_taxonomic import suite
 
